[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
![pipeline status](https://git.uni-luebeck.de/its/anomed/utilities/badges/main/pipeline.svg?ignore_skipped=true)
![coverage](https://git.uni-luebeck.de/its/anomed/utilities/badges/main/coverage.svg?job=run_tests)

# utilities

This repository provides basic utilities that might be handy when you contribute
your challenges, anonymizers or deanonymizers to the AnoMed platform. Mainly it
consists of …

- dataset preparation routines (regarding NumPy arrays)
- routines regarding web transmission of NumPy arrays
- convenience functions for building a flask app
